@@ -1,4 +1,4 @@
-//$Id: list.cc,v 1.13 2001/11/06 12:54:54 cactus Exp $ -*- c++ -*-
+//$Id: list.cc,v 1.14 2001/11/11 20:56:01 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -19,6 +19,8 @@
 #include "list.h"
 #include "list-canvas.h"
 
+#include "form-editor.h"
+
 using Guikachu::Widgets::List;
 using namespace Guikachu::GUI::FormEditor;
 
@@ -30,9 +32,10 @@ List::List (Resources::Form   *owner,
     visible_items (changed, 4),
     usable (changed, true),
     items (changed, std::vector<std::string> ()),
-    width (changed, 1),
-    manual_width (changed, false)
+    width (changed, 0),
+    manual_width (manual_width_changed, false)
 {
+    manual_width_changed.connect (SigC::slot (this, &List::manual_width_cb));
 }
 
 List::~List ()
@@ -81,8 +84,8 @@ bool List::load (StorageNode &node)
 	    usable = true;
 	else if (curr_node.name () == "items")
 	{
-	    curr_node.set_prop ("font", font);
-	    curr_node.set_prop ("visible", visible_items);
+	    font = curr_node.get_prop<int> ("font");
+	    visible_items = curr_node.get_prop<int> ("visible");
 	    
 	    /* Iterate items */
 	    std::vector<std::string> items_vec;
@@ -171,3 +174,28 @@ void List::save_rcp (std::ostream &ostr) const
 
     g_free (width_str);
 }
+
+int List::get_display_width ()
+{
+    if (manual_width && width != 0)
+	return width;
+    else
+	return get_auto_width ();
+}
+
+int List::get_auto_width ()
+{
+    int width = 18;
+    if (items ().size ())
+	width = get_string_width (font, items ()[0]) + 3;
+    
+    return width;
+}
+
+void List::manual_width_cb ()
+{
+    if (width == 0)
+	width = get_auto_width ();
+    else
+	changed.emit ();
+}
