@@ -1,4 +1,4 @@
-//$Id: list.h,v 1.8 2001/11/06 12:54:54 cactus Exp $ -*- c++ -*-
+//$Id: list.h,v 1.9 2001/11/11 20:56:01 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -40,6 +40,8 @@ namespace Guikachu
 	class List: public Widget
 	{
 	    GUI::FormEditor::ListProperties *editor;
+
+	    SigC::Signal0<void> manual_width_changed;
 	    
 	public:
 	    List (Resources::Form   *owner,
@@ -57,6 +59,12 @@ namespace Guikachu
 	    Property<std::vector<std::string> > items;
 	    Property<int>                       width;
 	    Property<bool>                      manual_width;
+
+	    int get_display_width ();
+	    int get_auto_width ();
+
+	private:
+	    void manual_width_cb ();
 	    
 	private:
 	    // Persistance
