@@ -1,4 +1,4 @@
-//$Id: popup-trigger.cc,v 1.12 2001/10/30 17:34:48 cactus Exp $ -*- c++ -*-
+//$Id: popup-trigger.cc,v 1.13 2001/11/06 12:54:54 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -21,13 +21,11 @@
 
 #include "form-editor.h"
 
-#include <gnome-xml/xmlmemory.h>
-
 using Guikachu::Widgets::PopupTrigger;
 using namespace Guikachu::GUI::FormEditor;
 
-PopupTrigger::PopupTrigger (Resources::Form *owner,
-			    const string& id):
+PopupTrigger::PopupTrigger (Resources::Form   *owner,
+			    const std::string &id):
     Widget (owner, id),
     Resizeable (changed),
     Textual (changed, id),
@@ -70,7 +68,7 @@ bool PopupTrigger::load (StorageNode &node)
 	    x = curr_node.get_prop<int> ("x");
 	    y = curr_node.get_prop<int> ("y");
 
-	    string width_str = curr_node.get_prop<string> ("width");
+	    std::string width_str = curr_node.get_prop<std::string> ("width");
 	    if (width_str == "auto")
 	    {
 		manual_width = false;
@@ -80,7 +78,7 @@ bool PopupTrigger::load (StorageNode &node)
 		width = atoi (width_str.c_str ());
 	    }
 	    
-	    string height_str = curr_node.get_prop<string> ("height");
+	    std::string height_str = curr_node.get_prop<std::string> ("height");
 	    if (height_str == "auto")
 	    {
 		manual_height = false;
@@ -100,7 +98,7 @@ bool PopupTrigger::load (StorageNode &node)
 	else if (curr_node.name () == "anchor_right")
 	    anchor_right = true;
 	else if (curr_node.name () == "popuplist")
-	    list_id = curr_node.get_prop<string> ("id");
+	    list_id = curr_node.get_prop<std::string> ("id");
 	else
 	    g_warning ("Error parsing `popup-trigger' widget: "
 		       "unexpected element `%s'",
@@ -148,7 +146,7 @@ void PopupTrigger::save (StorageNode &node) const
 	node.add_node ("popuplist").set_prop ("id", list_id);
 }
 
-void PopupTrigger::save_rcp (ostream &ostr) const
+void PopupTrigger::save_rcp (std::ostream &ostr) const
 {
     gchar *width_str, *height_str;
 
@@ -174,10 +172,10 @@ void PopupTrigger::save_rcp (ostream &ostr) const
     else
 	ostr << " LEFTANCHOR";
     
-    ostr << endl;
+    ostr << std::endl;
 
     if (list_id != "")
-	ostr << "  POPUPLIST ID " << id << " " << list_id << endl;
+	ostr << "  POPUPLIST ID " << id << " " << list_id << std::endl;
     
     g_free (height_str);
     g_free (width_str);
