@@ -1,4 +1,4 @@
-//$Id: popup-trigger.h,v 1.9 2001/10/30 17:34:48 cactus Exp $ -*- c++ -*-
+//$Id: popup-trigger.h,v 1.10 2001/11/06 12:54:54 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -45,8 +45,8 @@ namespace Guikachu
 	    GUI::FormEditor::PopupTriggerProperties *editor;
 	    
 	public:
-	    PopupTrigger (Resources::Form *owner,
-			  const string& id);
+	    PopupTrigger (Resources::Form   *owner,
+			  const std::string &id);
 	    virtual ~PopupTrigger ();
 	    
 	    virtual Type get_type () const { return WIDGET_POPUP_TRIGGER; };
@@ -55,7 +55,6 @@ namespace Guikachu
 	    virtual Gtk::Widget                 *create_editor ();
 	    
 	    Properties::WidgetRef list_id;
-
 	    Property<bool>        usable;
 	    Property<bool>        anchor_right;
 
@@ -65,9 +64,9 @@ namespace Guikachu
 
 	private:
 	    // Persistance
-	    virtual bool load (StorageNode &node);
-	    virtual void save (StorageNode &node) const;
-	    virtual void save_rcp (ostream &ostr) const;
+	    virtual bool load (StorageNode      &node);
+	    virtual void save (StorageNode      &node) const;
+	    virtual void save_rcp (std::ostream &ostr) const;
 	};
     }
 }
