@@ -1,4 +1,4 @@
-//$Id: scrollbar-prop.cc,v 1.4 2001/09/27 22:23:46 cactus Exp $ -*- c++ -*-
+//$Id: scrollbar-prop.cc,v 1.5 2001/11/03 01:30:45 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -78,8 +78,7 @@ ScrollBarProperties::ScrollBarProperties (ScrollBar *res_):
     ResizeableProperties::add_controls (res, *proptable);
     
     proptable->show ();
-    property_editor = manage (proptable);
-    gtk_object_ref (GTK_OBJECT (property_editor->gtkobj ()));
+    property_editor = proptable;
 
     res->changed.connect (SigC::slot (this, &ScrollBarProperties::update));
 }
