@@ -1,4 +1,4 @@
-//$Id: scrollbar.h,v 1.7 2001/10/23 13:05:51 cactus Exp $ -*- c++ -*-
+//$Id: scrollbar.h,v 1.8 2001/11/06 12:54:54 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -42,7 +42,8 @@ namespace Guikachu
 	    GUI::FormEditor::ScrollBarProperties *editor;
 	    
 	public:
-	    ScrollBar (Resources::Form *owner, const string& id);
+	    ScrollBar (Resources::Form   *owner,
+		       const std::string &id);
 	    virtual ~ScrollBar ();
 	    
 	    virtual Type get_type () const { return WIDGET_SCROLLBAR; };
@@ -61,7 +62,7 @@ namespace Guikachu
 	    // Persistance
 	    virtual bool load (StorageNode &node);
 	    virtual void save (StorageNode &node) const;
-	    virtual void save_rcp (ostream &ostr) const;
+	    virtual void save_rcp (std::ostream &ostr) const;
 
 	private:
 	    void update ();
