@@ -1,4 +1,4 @@
-//$Id: selector-trigger.cc,v 1.12 2001/10/26 20:46:56 cactus Exp $ -*- c++ -*-
+//$Id: selector-trigger.cc,v 1.13 2001/11/06 12:54:54 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -21,13 +21,11 @@
 
 #include "form-editor.h"
 
-#include <gnome-xml/xmlmemory.h>
-
 using Guikachu::Widgets::SelectorTrigger;
 using namespace Guikachu::GUI::FormEditor;
 
-SelectorTrigger::SelectorTrigger (Resources::Form *owner,
-				  const string& id):
+SelectorTrigger::SelectorTrigger (Resources::Form   *owner,
+				  const std::string &id):
     Widget (owner, id),
     Resizeable (changed),
     Textual (changed, id),
@@ -69,7 +67,7 @@ bool SelectorTrigger::load (StorageNode &node)
 	    x = curr_node.get_prop<int> ("x");
 	    y = curr_node.get_prop<int> ("y");
 
-	    string width_str = curr_node.get_prop<string> ("width");
+	    std::string width_str = curr_node.get_prop<std::string> ("width");
 	    if (width_str == "auto")
 	    {
 		manual_width = false;
@@ -79,7 +77,7 @@ bool SelectorTrigger::load (StorageNode &node)
 		width = atoi (width_str.c_str ());
 	    }
 	    
-	    string height_str = curr_node.get_prop<string> ("height");
+	    std::string height_str = curr_node.get_prop<std::string> ("height");
 	    if (height_str == "auto")
 	    {
 		manual_height = false;
@@ -142,7 +140,7 @@ void SelectorTrigger::save (StorageNode &node) const
     my_node.set_prop ("font", font);
 }
 
-void SelectorTrigger::save_rcp (ostream &ostr) const
+void SelectorTrigger::save_rcp (std::ostream &ostr) const
 {
     gchar *width_str, *height_str;
 
@@ -168,7 +166,7 @@ void SelectorTrigger::save_rcp (ostream &ostr) const
     else
 	ostr << " LEFTANCHOR";
     
-    ostr << endl;
+    ostr << std::endl;
 
     g_free (height_str);
     g_free (width_str);
