@@ -1,4 +1,4 @@
-//$Id: table-canvas.cc,v 1.3 2001/10/09 16:37:13 cactus Exp $ -*- c++ -*-
+//$Id: table-canvas.cc,v 1.4 2001/11/06 12:54:54 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -92,7 +92,7 @@ void TableCanvasItem::update ()
     
     /* Column separators */
     int line_x = x1;
-    const vector<int> &columns = widget->column_width;
+    const std::vector<int> &columns = widget->column_width;
     int num_columns = widget->num_columns;
     for (int i = 0; i < num_columns; i++)
     {
