@@ -1,4 +1,4 @@
-//$Id: table-prop.cc,v 1.4 2001/11/03 01:30:45 cactus Exp $ -*- c++ -*-
+//$Id: table-prop.cc,v 1.5 2001/11/06 12:54:54 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -55,9 +55,9 @@ namespace
 		};
 	};
 	
-	Table                   *table;
-	Gtk::Table               col_list;
-	vector<spinbutton_pair>  spinbuttons;
+	Table                        *table;
+	Gtk::Table                    col_list;
+	std::vector<spinbutton_pair>  spinbuttons;
     public:
 	TableColEditor (Table *table);
 	~TableColEditor ();
@@ -153,7 +153,7 @@ TableColEditor::TableColEditor (Table *table_):
 
 TableColEditor::~TableColEditor ()
 {
-    for (vector<spinbutton_pair>::iterator i = spinbuttons.begin ();
+    for (std::vector<spinbutton_pair>::iterator i = spinbuttons.begin ();
 	 i != spinbuttons.end (); i++)
     {
 	delete i->label;
@@ -168,7 +168,7 @@ void TableColEditor::col_width_cb (unsigned int index)
     
     Gtk::SpinButton *spinbutton = spinbuttons[index].spinbutton;
     unsigned int new_val = spinbutton->get_value_as_int ();
-    vector<int> columns = table->column_width;
+    std::vector<int> columns = table->column_width;
 
     g_return_if_fail (index <= columns.size ());
     
@@ -183,7 +183,7 @@ void TableColEditor::update ()
     
     update_block = true;
     
-    const vector<int> &columns = table->column_width;
+    const std::vector<int> &columns = table->column_width;
     unsigned int displayed_num_columns = spinbuttons.size ();
     unsigned int num_columns = table->num_columns;
     
