@@ -1,4 +1,4 @@
-//$Id: menu-win.cc,v 1.15 2001/10/28 14:08:47 cactus Exp $ -*- c++ -*-
+//$Id: menu-win.cc,v 1.17 2001/11/06 17:04:30 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -21,7 +21,7 @@
 #include "config.h"
 #include <libgnome/libgnome.h>
 
-#ifdef USE_WM_ICONS
+#ifdef GUIKACHU_USE_WM_ICONS
 #include <libgnomeui/gnome-window-icon.h>
 #endif
 
@@ -29,6 +29,8 @@
 #include "argumentsink.h"
 
 using namespace Guikachu;
+using std::vector;
+using std::string;
 
 GUI::MenuWindow::MenuWindow (Guikachu::Resources::Menu *res_):
     res (res_),
@@ -42,7 +44,7 @@ GUI::MenuWindow::MenuWindow (Guikachu::Resources::Menu *res_):
     window = wrap (GTK_WINDOW (glade_xml_get_widget (gui, "res_menu")));
     window->delete_event.connect (slot (this, &MenuWindow::delete_event_impl));
 
-#ifdef USE_WM_ICONS
+#ifdef GUIKACHU_USE_WM_ICONS
     gnome_window_icon_set_from_file (window->gtkobj (), GNOME_ICONDIR "/guikachu.png");
 #endif    
 
