@@ -1,4 +1,4 @@
-//$Id: propertytable.cc,v 1.8 2001/11/03 19:18:32 cactus Exp $ -*- c++ -*-
+//$Id: propertytable.cc,v 1.12 2001/11/10 15:13:00 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -38,6 +38,7 @@ PropertyTable::PropertyTable ():
     set_col_spacings (5);
 
     parent_changed.connect (SigC::slot (this, &PropertyTable::parent_changed_cb));
+    map_.connect (SigC::slot (this, &PropertyTable::map_cb));
 }
 
 PropertyTable::~PropertyTable ()
@@ -45,9 +46,9 @@ PropertyTable::~PropertyTable ()
     accel_group->unref ();
 }
 
-Gtk::Widget *PropertyTable::create_label (const string &label,
-					  Gtk::Widget  &control,
-					  const string &tooltip)
+Gtk::Widget *PropertyTable::create_label (const std::string &label,
+					  Gtk::Widget       &control,
+					  const std::string &tooltip)
 {
     Gtk::Widget  *ret_val;
     Gtk::Label   *label_widget = new Gtk::Label (label, 1, 0.5);
@@ -90,9 +91,9 @@ Gtk::Widget *PropertyTable::create_label (const string &label,
 }
 
     
-void PropertyTable::add (const string& label,
-			 Gtk::Widget& control,
-			 const string& tooltip = "")
+void PropertyTable::add (const std::string &label,
+			 Gtk::Widget       &control,
+			 const std::string &tooltip = "")
 {
     
     Gtk::Text *text;
@@ -122,9 +123,9 @@ void PropertyTable::add (const string& label,
     curr_row++;
 }
 
-void PropertyTable::add (const string  &label,
-			 Gtk::Text     &control,
-			 const string  &tooltip = "")
+void PropertyTable::add (const std::string  &label,
+			 Gtk::Text          &control,
+			 const std::string  &tooltip = "")
 {
     Gtk::Widget *label_widget = create_label (label, control, tooltip);
     Gtk::Alignment *alignment = new Gtk::Alignment (0.5, 0, 1, 0);
@@ -165,52 +166,20 @@ void PropertyTable::parent_changed_cb (Gtk::Widget *old_parent)
 {
     if (old_parent)
     {
-	Gtk::Window *old_window = old_parent->get_toplevel ();
-	if (old_window && GTK_IS_WINDOW (old_window->gtkobj ()))
+	Gtk::Widget *old_toplevel = Gtk::wrap (
+	    gtk_widget_get_toplevel (old_parent->gtkobj ()));	
+
+	Gtk::Window *old_window = dynamic_cast<Gtk::Window*> (old_toplevel);
+	
+	if (old_window)
 	    old_window->remove_accel_group (*accel_group);
     }
+}
 
+void PropertyTable::map_cb ()
+{
     GtkWidget *new_parent = gtk_widget_get_toplevel (GTK_WIDGET (gtkobj ()));
 
-    // if new_parent is not a GtkWindow, it means our parent is an
-    // intermediate container not yet added to a window
-
-    if (new_parent && new_parent != GTK_WIDGET (gtkobj ()))
-    {
-	if (GTK_IS_WINDOW (new_parent))
-	    Gtk::wrap (GTK_WINDOW (new_parent))->add_accel_group (*accel_group);
-	else
-	{
-	    Gtk::Widget *new_parent_w = Gtk::wrap (new_parent);
-	    
-	    new_parent_w->parent_changed.connect (
-		SigC::bind (SigC::slot (this, &PropertyTable::parent_changed_delegated_cb),
-			    new_parent_w));
-	}
-    }
-}
-
-void PropertyTable::parent_changed_delegated_cb (Gtk::Widget *old_parent,
-						 Gtk::Widget *widget)
-{
-    if (old_parent && old_parent != widget)
-    {
-	Gtk::Window *old_window = old_parent->get_toplevel ();
-	if (old_window && GTK_IS_WINDOW (old_window->gtkobj ()))
-	    old_window->remove_accel_group (*accel_group);
-    }
-
-    GtkWidget *new_parent = gtk_widget_get_toplevel (GTK_WIDGET (widget->gtkobj ()));
-
-    // if new_parent is not a GtkWindow, it means our parent is an
-    // intermediate container not yet added to a window
-
-    if (new_parent && new_parent != GTK_WIDGET (widget->gtkobj ()))
-    {
-	if (GTK_IS_WINDOW (new_parent))
-	    Gtk::wrap (GTK_WINDOW (new_parent))->add_accel_group (*accel_group);
-	else
-	    Gtk::wrap (GTK_WIDGET (new_parent))->parent_changed.connect (
-		SigC::slot (this, &PropertyTable::parent_changed_cb));
-    }
+    if (new_parent && GTK_IS_WINDOW (new_parent))
+	Gtk::wrap (GTK_WINDOW (new_parent))->add_accel_group (*accel_group);
 }
